@@ -8,7 +8,7 @@
 #define __LEDMETER_H__
 
 #include <qframe.h>
-#include <qlist.h>
+#include <qptrlist.h>
 
 
 class KALedMeter : public QFrame
@@ -47,7 +47,7 @@ protected:
     int mCount;
     int mCurrentCount;
     int mValue;
-    QList<ColorRange> mCRanges;
+    QPtrList<ColorRange> mCRanges;
 };
 
 #endif
