@@ -4,7 +4,7 @@
    ------------------------------------------------------------------------- */
 
 /****************************************************************************
-** $Id: GameTimer.h 328003 2004-07-11 17:28:31Z aacid $
+** $Id: GameTimer.h 650394 2007-04-04 12:46:34Z mueller $
 **
 ** Copyright (C) 1992-1998 Troll Tech AS.  All rights reserved.
 **
@@ -28,7 +28,7 @@ public:
     GameTimer( QWidget *parent=0, const char *name=0 );
 
     int toInt(); 
-    QString toString() {return theTimer.toString();};	
+    QString toString() {return theTimer.toString();}	
     void fromString(const char *);
 
 protected:					// event handlers
