@@ -36,7 +36,7 @@ enum fcs_presets_ids
     FCS_PRESET_SEAHAVEN_TOWERS,
     FCS_PRESET_SIMPLE_SIMON,
     FCS_PRESET_YUKON,
-    FCS_PRESET_BELEAGUERED_CASTLE,
+    FCS_PRESET_BELEAGUERED_CASTLE
 };
 
 static const fcs_preset_t fcs_presets[16] = 
